@@ -37,9 +37,11 @@
 #include <qregexp.h>            // Portable regular expressions
 #include <qdatetime.h>
 #include <qmessagebox.h>
+#include <qtextstream.h>
+#include <qpopupmenu.h>
+#include <qfile.h>
 
 // User interface
-#include "as_gui.h"             // Main classes
 #include "as_const.h"           // Application constants
 #include "as_tableitem.h"       // For class RtTableItem
 #include "as_crc.h"             // For quality strings
