@@ -101,7 +101,7 @@ Prefpanel::Prefpanel(QWidget *pParent, const char *kszName, bool bModal, WFlags
 
     // Optional file backups with hard coded extension .bak
     m_pBackupcheck = new QCheckBox(m_pSwitchgroup, "Backupbutton");
-    m_pBackupcheck->setText(tr("Leave a .bak file", "Comment for Backupcheck"));
+    m_pBackupcheck->setText(tr("Make .bak file on save", "Comment for Backupcheck"));
     QToolTip::add(m_pBackupcheck, tr("Will make a .bak file when saving", "Comment for toolTip Backupcheck"));
     QWhatsThis::add(m_pBackupcheck, tr("Check this box to enable automatic file backups when overwriting an existing file", "Comment whatsThis for Backupcheck"));
     m_pSwitchlay->addWidget(m_pBackupcheck);
