@@ -39,6 +39,9 @@
 #include <qclipboard.h>
 #include <qmenudata.h>
 #include <qdatastream.h>
+#include <qstatusbar.h>
+#include <qaction.h>
+#include <qpopupmenu.h>
 
 // Qt style headers
 #include <qcdestyle.h>
@@ -49,7 +52,6 @@
 #include <qwindowsstyle.h>
 
 // User interface
-#include "as_gui.h"             // Main classes
 #include "as_const.h"           // Application constants
 #include "as_except.h"          // Exception classes
 #include "as_tableitem.h"       // For our custom table items
@@ -1255,6 +1257,21 @@ void Titraqform::showViewbar(void)
     }
 }
 
+//
+// View menu show prefs toolbar
+//
+void Titraqform::showPrefsbar(void)
+{
+    if (m_pPrefstools->isVisible()) {
+        m_pPrefstools->hide();
+        m_pTbarspopup->setItemChecked(m_pTbarspopup->idAt(TITRAQ_IDXPREFBAR), false);
+    }
+    else {
+        m_pPrefstools->show();
+        m_pTbarspopup->setItemChecked(m_pTbarspopup->idAt(TITRAQ_IDXPREFBAR), true);
+    }
+}
+
 //
 // View menu show whats this toolbar
 //
@@ -1751,6 +1768,8 @@ void Titraqform::savePrefs(void)
     // Get check status from toolbar menu and pass it to prefs handler
     m_pPrefs->setBool(TITRAQ_PREFFILEBAR, m_pTbarspopup->isItemChecked(m_pTbarspopup->idAt(TITRAQ_IDXFILEBAR)));
     m_pPrefs->setBool(TITRAQ_PREFEDITBAR, m_pTbarspopup->isItemChecked(m_pTbarspopup->idAt(TITRAQ_IDXEDITBAR)));
+    m_pPrefs->setBool(TITRAQ_PREFVIEWBAR, m_pTbarspopup->isItemChecked(m_pTbarspopup->idAt(TITRAQ_IDXVIEWBAR)));
+    m_pPrefs->setBool(TITRAQ_PREFPREFBAR, m_pTbarspopup->isItemChecked(m_pTbarspopup->idAt(TITRAQ_IDXPREFBAR)));
     m_pPrefs->setBool(TITRAQ_PREFWHATBAR, m_pTbarspopup->isItemChecked(m_pTbarspopup->idAt(TITRAQ_IDXWHATBAR)));
 
     // Get column widths from main table and pass it to prefs handler
